=======
LoomXpy
=======

Python package (compatible with SCope) to create .loom files and extend them with other data e.g.: SCENIC regulons

.. image:: https://img.shields.io/pypi/v/loomxpy.svg
        :target: https://pypi.python.org/pypi/loomxpy

.. image:: https://readthedocs.org/projects/loomxpy/badge/?version=latest
        :target: https://loomxpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/aertslab/loomxpy/shield.svg
     :target: https://pyup.io/repos/github/aertslab/loomxpy/
     :alt: Updates



Python package containing code for Loom files generation.


* Free software: MIT
* Documentation: https://loomxpy.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
